"""
 Tests for `corsika.io.outputs.energy_loss`

 (c) Copyright 2018 CORSIKA Project, corsika-project@lists.kit.edu

 This software is distributed under the terms of the GNU General Public
 Licence version 3 (GPL Version 3). See file LICENSE for a full version of
 the license.
"""
import os
import os.path as op
import subprocess

import pytest

from corsika.io import Library

from .. import build_directory

bindir = op.join(build_directory, "bin")


def generate_data() -> str:
    """
    Generate a test with `testSaveBoostHistogram`.

    Returns
    -------
    str
        The path to the generated histogram.
    bool
        If True, this file was regenerated.
    """

    # we construct the name of the bin
    bin = op.join(bindir, "testOutput")

    output_dir = op.join(os.getcwd(), "out_test/check")

    if not op.exists(output_dir):  # only make if not already run
        subprocess.call([bin, "OutputManager"])

    return output_dir


def test_basic_Library() -> None:
    dir_to_test = generate_data()
    lib = Library(dir_to_test)

    assert 0 == len(lib.names)
    assert len(lib.summary)
    assert len(lib.config)

    lib.get("Does not exits")


def test_bad_Library() -> None:
    with pytest.raises(ValueError):
        Library("This does not exist")
